.. _examples:

========
Examples
========

Forecasting
===========

.. nbgallery::
    :glob:

    examples/01_forecasting.ipynb
    examples/01a_forecasting_sklearn.ipynb
    examples/01b_forecasting_proba.ipynb
    examples/forecasting/*

Classification
==============

.. nbgallery::
    :glob:

    examples/02_classification.ipynb
    examples/classification/*

Regression
==========

To come!

Clustering
==========

.. nbgallery::
    :glob:

    examples/clustering/*

Annotation
==========

.. nbgallery::
    :glob:

    examples/annotation/*

Transformation
==============

.. nbgallery::
    :glob:

    examples/transformation/*

Data
====

.. nbgallery::
    :glob:

    examples/AA_datatypes_and_datasets.ipynb
    examples/data/*

Other
=====

.. nbgallery::
    :glob:

    examples/04_benchmarking.ipynb
    examples/other/*
